@@ -6,7 +6,7 @@ Mojo::IRC - IRC Client for the Mojo IOLoop
 
 =head1 VERSION
 
-0.24
+0.25
 
 =head1 SYNOPSIS
 
@@ -117,7 +117,7 @@ use constant DEFAULT_CERT => $ENV{MOJO_IRC_CERT_FILE} || catfile dirname(__FILE_
 use constant DEFAULT_KEY  => $ENV{MOJO_IRC_KEY_FILE}  || catfile dirname(__FILE__), 'mojo-irc-client.key';
 use constant OFFLINE => $ENV{MOJO_IRC_OFFLINE} ? 1 : 0;
 
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 
 my %CTCP_QUOTE = ("\012" => 'n', "\015" => 'r', "\0" => '0', "\cP" => "\cP");
 
@@ -566,7 +566,7 @@ sub _read {
   $self->{buffer} .= Unicode::UTF8::decode_utf8($_[0], sub { $_[0] });
 
 CHUNK:
-  while ($self->{buffer} =~ s/^([^\r\n]+)\r\n//m) {
+  while ($self->{buffer} =~ s/^([^\015\012]+)[\015\012]//m) {
     warn "[$self->{debug_key}] >>> $1\n" if DEBUG;
     my $message = $self->parser->parse($1);
     my $command = $message->{command} or next CHUNK;
